## Original Authors:

* Diederik van der Boor (@vdboor)

### Contributors:

* Aarni Koskela
* Adrián López Calvo (https://github.com/AdrianLC)
* Dan Wilson
* Jacob Rief <jacob.rief@gmail.com>
* Tuomas Suutari
* you?
